==> openflowplugin-extension-nicira-0.10.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/nx/action/conntrack/grouping/NxConntrackBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.conntrack.grouping;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Integer;
import java.lang.Long;
import java.lang.Object;
import java.lang.Override;
import java.lang.Short;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.conntrack.grouping.nx.conntrack.CtActions;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.Uint16;
import org.opendaylight.yangtools.yang.common.Uint32;
import org.opendaylight.yangtools.yang.common.Uint8;

/**
 * Class that builds {@link NxConntrackBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     NxConntrackBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new NxConntrackBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of NxConntrackBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see NxConntrackBuilder
 * @see Builder
 *
 */
public class NxConntrackBuilder implements Builder<NxConntrack> {

    private Uint16 _conntrackZone;
    private List<CtActions> _ctActions;
    private Uint16 _flags;
    private Uint8 _recircTable;
    private Uint32 _zoneSrc;


    Map<Class<? extends Augmentation<NxConntrack>>, Augmentation<NxConntrack>> augmentation = Collections.emptyMap();

    public NxConntrackBuilder() {
    }

    public NxConntrackBuilder(NxConntrack base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<NxConntrack>>, Augmentation<NxConntrack>> aug =((AugmentationHolder<NxConntrack>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._conntrackZone = base.getConntrackZone();
        this._ctActions = base.getCtActions();
        this._flags = base.getFlags();
        this._recircTable = base.getRecircTable();
        this._zoneSrc = base.getZoneSrc();
    }


    public Uint16 getConntrackZone() {
        return _conntrackZone;
    }
    
    public List<CtActions> getCtActions() {
        return _ctActions;
    }
    
    public Uint16 getFlags() {
        return _flags;
    }
    
    public Uint8 getRecircTable() {
        return _recircTable;
    }
    
    public Uint32 getZoneSrc() {
        return _zoneSrc;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<NxConntrack>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public NxConntrackBuilder setConntrackZone(final Uint16 value) {
        this._conntrackZone = value;
        return this;
    }
    
    /**
     * Utility migration setter.
     *
     * @param value field value in legacy type
     * @return this builder
     * @deprecated Use {#link setConntrackZone(Uint16)} instead.
     */
    @Deprecated(forRemoval = true)
    public NxConntrackBuilder setConntrackZone(final Integer value) {
        return setConntrackZone(CodeHelpers.compatUint(value));
    }
    public NxConntrackBuilder setCtActions(final List<CtActions> values) {
        this._ctActions = values;
        return this;
    }
    
    
    public NxConntrackBuilder setFlags(final Uint16 value) {
        this._flags = value;
        return this;
    }
    
    /**
     * Utility migration setter.
     *
     * @param value field value in legacy type
     * @return this builder
     * @deprecated Use {#link setFlags(Uint16)} instead.
     */
    @Deprecated(forRemoval = true)
    public NxConntrackBuilder setFlags(final Integer value) {
        return setFlags(CodeHelpers.compatUint(value));
    }
    
    public NxConntrackBuilder setRecircTable(final Uint8 value) {
        this._recircTable = value;
        return this;
    }
    
    /**
     * Utility migration setter.
     *
     * @param value field value in legacy type
     * @return this builder
     * @deprecated Use {#link setRecircTable(Uint8)} instead.
     */
    @Deprecated(forRemoval = true)
    public NxConntrackBuilder setRecircTable(final Short value) {
        return setRecircTable(CodeHelpers.compatUint(value));
    }
    
    public NxConntrackBuilder setZoneSrc(final Uint32 value) {
        this._zoneSrc = value;
        return this;
    }
    
    /**
     * Utility migration setter.
     *
     * @param value field value in legacy type
     * @return this builder
     * @deprecated Use {#link setZoneSrc(Uint32)} instead.
     */
    @Deprecated(forRemoval = true)
    public NxConntrackBuilder setZoneSrc(final Long value) {
        return setZoneSrc(CodeHelpers.compatUint(value));
    }
    
    public NxConntrackBuilder addAugmentation(Class<? extends Augmentation<NxConntrack>> augmentationType, Augmentation<NxConntrack> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public NxConntrackBuilder removeAugmentation(Class<? extends Augmentation<NxConntrack>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public NxConntrack build() {
        return new NxConntrackImpl(this);
    }

    private static final class NxConntrackImpl
        extends AbstractAugmentable<NxConntrack>
        implements NxConntrack {
    
        private final Uint16 _conntrackZone;
        private final List<CtActions> _ctActions;
        private final Uint16 _flags;
        private final Uint8 _recircTable;
        private final Uint32 _zoneSrc;
    
        NxConntrackImpl(NxConntrackBuilder base) {
            super(base.augmentation);
            this._conntrackZone = base.getConntrackZone();
            this._ctActions = base.getCtActions();
            this._flags = base.getFlags();
            this._recircTable = base.getRecircTable();
            this._zoneSrc = base.getZoneSrc();
        }
    
        @Override
        public Uint16 getConntrackZone() {
            return _conntrackZone;
        }
        
        @Override
        public List<CtActions> getCtActions() {
            return _ctActions;
        }
        
        @Override
        public Uint16 getFlags() {
            return _flags;
        }
        
        @Override
        public Uint8 getRecircTable() {
            return _recircTable;
        }
        
        @Override
        public Uint32 getZoneSrc() {
            return _zoneSrc;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_conntrackZone);
            result = prime * result + Objects.hashCode(_ctActions);
            result = prime * result + Objects.hashCode(_flags);
            result = prime * result + Objects.hashCode(_recircTable);
            result = prime * result + Objects.hashCode(_zoneSrc);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!NxConntrack.class.equals(((DataObject)obj).implementedInterface())) {
                return false;
            }
            NxConntrack other = (NxConntrack)obj;
            if (!Objects.equals(_conntrackZone, other.getConntrackZone())) {
                return false;
            }
            if (!Objects.equals(_ctActions, other.getCtActions())) {
                return false;
            }
            if (!Objects.equals(_flags, other.getFlags())) {
                return false;
            }
            if (!Objects.equals(_recircTable, other.getRecircTable())) {
                return false;
            }
            if (!Objects.equals(_zoneSrc, other.getZoneSrc())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                NxConntrackImpl otherImpl = (NxConntrackImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<NxConntrack>>, Augmentation<NxConntrack>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("NxConntrack");
            CodeHelpers.appendValue(helper, "_conntrackZone", _conntrackZone);
            CodeHelpers.appendValue(helper, "_ctActions", _ctActions);
            CodeHelpers.appendValue(helper, "_flags", _flags);
            CodeHelpers.appendValue(helper, "_recircTable", _recircTable);
            CodeHelpers.appendValue(helper, "_zoneSrc", _zoneSrc);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}

==> openflowplugin-extension-nicira-0.11.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/nx/action/conntrack/grouping/NxConntrackBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.conntrack.grouping;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Deprecated;
import java.lang.Integer;
import java.lang.Long;
import java.lang.Object;
import java.lang.Override;
import java.lang.Short;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.conntrack.grouping.nx.conntrack.CtActions;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.Uint16;
import org.opendaylight.yangtools.yang.common.Uint32;
import org.opendaylight.yangtools.yang.common.Uint8;

/**
 * Class that builds {@link NxConntrackBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     NxConntrackBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new NxConntrackBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of NxConntrackBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see NxConntrackBuilder
 * @see Builder
 *
 */
public class NxConntrackBuilder implements Builder<NxConntrack> {

    private Uint16 _conntrackZone;
    private List<CtActions> _ctActions;
    private Uint16 _flags;
    private Uint8 _recircTable;
    private Uint32 _zoneSrc;


    Map<Class<? extends Augmentation<NxConntrack>>, Augmentation<NxConntrack>> augmentation = Collections.emptyMap();

    public NxConntrackBuilder() {
    }

    public NxConntrackBuilder(NxConntrack base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<NxConntrack>>, Augmentation<NxConntrack>> aug =((AugmentationHolder<NxConntrack>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._conntrackZone = base.getConntrackZone();
        this._ctActions = base.getCtActions();
        this._flags = base.getFlags();
        this._recircTable = base.getRecircTable();
        this._zoneSrc = base.getZoneSrc();
    }


    public Uint16 getConntrackZone() {
        return _conntrackZone;
    }
    
    public List<CtActions> getCtActions() {
        return _ctActions;
    }
    
    public Uint16 getFlags() {
        return _flags;
    }
    
    public Uint8 getRecircTable() {
        return _recircTable;
    }
    
    public Uint32 getZoneSrc() {
        return _zoneSrc;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<NxConntrack>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(Objects.requireNonNull(augmentationType));
    }

    
    public NxConntrackBuilder setConntrackZone(final Uint16 value) {
        this._conntrackZone = value;
        return this;
    }
    
    /**
     * Utility migration setter.
     *
     * @param value field value in legacy type
     * @return this builder
     * @deprecated Use {#link setConntrackZone(Uint16)} instead.
     */
    @Deprecated(forRemoval = true)
    public NxConntrackBuilder setConntrackZone(final Integer value) {
        return setConntrackZone(CodeHelpers.compatUint(value));
    }
    public NxConntrackBuilder setCtActions(final List<CtActions> values) {
        this._ctActions = values;
        return this;
    }
    
    
    public NxConntrackBuilder setFlags(final Uint16 value) {
        this._flags = value;
        return this;
    }
    
    /**
     * Utility migration setter.
     *
     * @param value field value in legacy type
     * @return this builder
     * @deprecated Use {#link setFlags(Uint16)} instead.
     */
    @Deprecated(forRemoval = true)
    public NxConntrackBuilder setFlags(final Integer value) {
        return setFlags(CodeHelpers.compatUint(value));
    }
    
    public NxConntrackBuilder setRecircTable(final Uint8 value) {
        this._recircTable = value;
        return this;
    }
    
    /**
     * Utility migration setter.
     *
     * @param value field value in legacy type
     * @return this builder
     * @deprecated Use {#link setRecircTable(Uint8)} instead.
     */
    @Deprecated(forRemoval = true)
    public NxConntrackBuilder setRecircTable(final Short value) {
        return setRecircTable(CodeHelpers.compatUint(value));
    }
    
    public NxConntrackBuilder setZoneSrc(final Uint32 value) {
        this._zoneSrc = value;
        return this;
    }
    
    /**
     * Utility migration setter.
     *
     * @param value field value in legacy type
     * @return this builder
     * @deprecated Use {#link setZoneSrc(Uint32)} instead.
     */
    @Deprecated(forRemoval = true)
    public NxConntrackBuilder setZoneSrc(final Long value) {
        return setZoneSrc(CodeHelpers.compatUint(value));
    }
    
    /**
      * Add an augmentation to this builder's product.
      *
      * @param augmentation augmentation to be added
      * @return this builder
      * @throws NullPointerException if {@code augmentation} is null
      */
    public NxConntrackBuilder addAugmentation(Augmentation<NxConntrack> augmentation) {
        return doAddAugmentation(augmentation.implementedInterface(), augmentation);
    }
    
    /**
      * Add or remove an augmentation to this builder's product.
      *
      * @param augmentationType augmentation type to be added or removed
      * @param augmentationValue augmentation value, null if the augmentation type should be removed
      * @return this builder
      * @deprecated Use either {@link #addAugmentation(Augmentation)} or {@link #removeAugmentation(Class)} instead.
      */
    @Deprecated(forRemoval = true)
    public NxConntrackBuilder addAugmentation(Class<? extends Augmentation<NxConntrack>> augmentationType, Augmentation<NxConntrack> augmentationValue) {
        return augmentationValue == null ? removeAugmentation(augmentationType) : doAddAugmentation(augmentationType, augmentationValue);
    }
    
    /**
      * Remove an augmentation from this builder's product. If this builder does not track such an augmentation
      * type, this method does nothing.
      *
      * @param augmentationType augmentation type to be removed
      * @return this builder
      */
    public NxConntrackBuilder removeAugmentation(Class<? extends Augmentation<NxConntrack>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }
    
    private NxConntrackBuilder doAddAugmentation(Class<? extends Augmentation<NxConntrack>> augmentationType, Augmentation<NxConntrack> augmentationValue) {
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }

    @Override
    public NxConntrack build() {
        return new NxConntrackImpl(this);
    }

    private static final class NxConntrackImpl
        extends AbstractAugmentable<NxConntrack>
        implements NxConntrack {
    
        private final Uint16 _conntrackZone;
        private final List<CtActions> _ctActions;
        private final Uint16 _flags;
        private final Uint8 _recircTable;
        private final Uint32 _zoneSrc;
    
        NxConntrackImpl(NxConntrackBuilder base) {
            super(base.augmentation);
            this._conntrackZone = base.getConntrackZone();
            this._ctActions = CodeHelpers.emptyToNull(base.getCtActions());
            this._flags = base.getFlags();
            this._recircTable = base.getRecircTable();
            this._zoneSrc = base.getZoneSrc();
        }
    
        @Override
        public Uint16 getConntrackZone() {
            return _conntrackZone;
        }
        
        @Override
        public List<CtActions> getCtActions() {
            return _ctActions;
        }
        
        @Override
        public Uint16 getFlags() {
            return _flags;
        }
        
        @Override
        public Uint8 getRecircTable() {
            return _recircTable;
        }
        
        @Override
        public Uint32 getZoneSrc() {
            return _zoneSrc;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_conntrackZone);
            result = prime * result + Objects.hashCode(_ctActions);
            result = prime * result + Objects.hashCode(_flags);
            result = prime * result + Objects.hashCode(_recircTable);
            result = prime * result + Objects.hashCode(_zoneSrc);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!NxConntrack.class.equals(((DataObject)obj).implementedInterface())) {
                return false;
            }
            NxConntrack other = (NxConntrack)obj;
            if (!Objects.equals(_conntrackZone, other.getConntrackZone())) {
                return false;
            }
            if (!Objects.equals(_ctActions, other.getCtActions())) {
                return false;
            }
            if (!Objects.equals(_flags, other.getFlags())) {
                return false;
            }
            if (!Objects.equals(_recircTable, other.getRecircTable())) {
                return false;
            }
            if (!Objects.equals(_zoneSrc, other.getZoneSrc())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                NxConntrackImpl otherImpl = (NxConntrackImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<NxConntrack>>, Augmentation<NxConntrack>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("NxConntrack");
            CodeHelpers.appendValue(helper, "_conntrackZone", _conntrackZone);
            CodeHelpers.appendValue(helper, "_ctActions", _ctActions);
            CodeHelpers.appendValue(helper, "_flags", _flags);
            CodeHelpers.appendValue(helper, "_recircTable", _recircTable);
            CodeHelpers.appendValue(helper, "_zoneSrc", _zoneSrc);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}
